@@ -25,7 +25,6 @@ from sqlalchemy.orm import registry
 from sqlalchemy import sql
 
 from oslo_db import exception
-from oslo_db.sqlalchemy import compat
 from oslo_db.sqlalchemy import engines
 from oslo_db.sqlalchemy import exc_filters
 from oslo_db.sqlalchemy import utils
@@ -150,16 +149,13 @@ class TestsExceptionFilter(_SQLAExceptionMatcher, test_base.BaseTestCase):
             mock.patch.object(engine.dialect, "name", dialect_name),
             mock.patch.object(engine.dialect,
                               "is_disconnect",
-                              lambda *args: is_disconnect)
-        ]
-        if compat.sqla_2:
-            patches.append(
-                mock.patch.object(
-                    engine.dialect,
-                    "loaded_dbapi",
-                    mock.Mock(Error=self.Error),
-                )
+                              lambda *args: is_disconnect),
+            mock.patch.object(
+                engine.dialect,
+                "loaded_dbapi",
+                mock.Mock(Error=self.Error),
             )
+        ]
 
         with test_utils.nested(*patches):
             yield
@@ -756,7 +752,7 @@ class TestExceptionCauseMySQLSavepoint(
             session.execute(sql.text("select 1"))
 
             # close underying DB connection
-            compat.driver_connection(session.connection()).close()
+            session.connection().connection.driver_connection.close()
 
             # alternate approach, but same idea:
             # conn_id = session.scalar("select connection_id()")
@@ -781,7 +777,7 @@ class TestExceptionCauseMySQLSavepoint(
             session.execute(sql.text("select 1"))
 
             # close underying DB connection
-            compat.driver_connection(session.connection()).close()
+            session.connection().connection.driver_connection.close()
 
             # alternate approach, but same idea:
             # conn_id = session.scalar("select connection_id()")
@@ -1053,6 +1049,48 @@ class TestDeadlock(TestsExceptionFilter):
         )
 
 
+class TestMariaDBConsistencyError(TestsExceptionFilter):
+    """Test MariaDB consistency error detection."""
+
+    statement = ('UPDATE users SET status = :status_1 '
+                 'WHERE users.id = :id_1')
+    params = {
+        'status_1': 'active',
+        'id_1': 123
+    }
+
+    def _run_consistency_error_test(
+        self, dialect_name, message,
+        orig_exception_cls=TestsExceptionFilter.OperationalError):
+        self._run_test(
+            dialect_name, self.statement,
+            orig_exception_cls(message),
+            exception.DBConsistencyError,
+            params=self.params
+        )
+
+    def test_mariadb_pymysql_consistency_error(self):
+        self._run_consistency_error_test(
+            "mysql",
+            "(1020, \"Record has changed since "
+            "last read in table 'test_table'\")"
+        )
+
+    def test_mariadb_mysqlconnector_consistency_error(self):
+        self._run_consistency_error_test(
+            "mysql",
+            "1020 (HY000): Record has changed since "
+            "last read in table 'test_table'"
+        )
+
+    def test_mariadb_consistency_error_with_details(self):
+        self._run_consistency_error_test(
+            "mysql",
+            "(1020, \"Record has changed since last read "
+            "in table 'users' (transaction id 12345)\")"
+        )
+
+
 class TestDataError(TestsExceptionFilter):
     def _run_bad_data_test(self, dialect_name, message, error_class):
         self._run_test(dialect_name,
@@ -1187,8 +1225,6 @@ class IntegrationTest(db_test_base._DbTestCase):
 
 
 class TestDBDisconnectedFixture(TestsExceptionFilter):
-    native_pre_ping = False
-
     def _test_ping_listener_disconnected(
         self, dialect_name, exc_obj, is_disconnect=True,
     ):
@@ -1288,13 +1324,8 @@ class TestDBDisconnectedFixture(TestsExceptionFilter):
         else:
             raise NotImplementedError()
 
-        with mock.patch.object(
-            compat,
-            "native_pre_ping_event_support",
-            self.native_pre_ping,
-        ):
-            engine = engines.create_engine(
-                self.engine.url, max_retries=0)
+        engine = engines.create_engine(
+            self.engine.url, max_retries=0)
 
         # 1.  override how we connect.   if we want the DB to be down
         # for the moment, but recover, reset db_disconnected after
@@ -1431,106 +1462,6 @@ class PostgreSQLPrePingHandlerTests(
         )
 
 
-if compat.sqla_2:
-    class MySQLNativePrePingTests(MySQLPrePingHandlerTests):
-        native_pre_ping = True
-
-    class PostgreSQLNativePrePingTests(PostgreSQLPrePingHandlerTests):
-        native_pre_ping = True
-
-
-class TestDBConnectPingListener(TestsExceptionFilter):
-
-    def setUp(self):
-        super().setUp()
-        event.listen(
-            self.engine, "engine_connect", engines._connect_ping_listener)
-
-    @contextlib.contextmanager
-    def _fixture(
-            self, dialect_name, exception, good_conn_count,
-            is_disconnect=True):
-        engine = self.engine
-
-        # empty out the connection pool
-        engine.dispose()
-
-        connect_fn = engine.dialect.connect
-        real_do_execute = engine.dialect.do_execute
-
-        counter = itertools.count(1)
-
-        def cant_execute(*arg, **kw):
-            value = next(counter)
-            if value > good_conn_count:
-                raise exception
-            else:
-                return real_do_execute(*arg, **kw)
-
-        def cant_connect(*arg, **kw):
-            value = next(counter)
-            if value > good_conn_count:
-                raise exception
-            else:
-                return connect_fn(*arg, **kw)
-
-        with self._dbapi_fixture(dialect_name, is_disconnect=is_disconnect):
-            with mock.patch.object(engine.dialect, "connect", cant_connect):
-                with mock.patch.object(
-                        engine.dialect, "do_execute", cant_execute):
-                    yield
-
-    def _test_ping_listener_disconnected(
-            self, dialect_name, exc_obj, is_disconnect=True):
-        with self._fixture(dialect_name, exc_obj, 3, is_disconnect):
-            conn = self.engine.connect()
-            self.assertEqual(1, conn.scalar(sqla.select(1)))
-            conn.close()
-
-        with self._fixture(dialect_name, exc_obj, 1, is_disconnect):
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-
-        with self._fixture(dialect_name, exc_obj, 1, is_disconnect):
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-            self.assertRaises(
-                exception.DBConnectionError,
-                self.engine.connect
-            )
-
-    def test_mysql_w_disconnect_flag(self):
-        for code in [2002, 2003, 2002]:
-            self._test_ping_listener_disconnected(
-                "mysql",
-                self.OperationalError('%d MySQL server has gone away' % code)
-            )
-
-    def test_mysql_wo_disconnect_flag(self):
-        for code in [2002, 2003]:
-            self._test_ping_listener_disconnected(
-                "mysql",
-                self.OperationalError('%d MySQL server has gone away' % code),
-                is_disconnect=False
-            )
-
-
 class TestDBConnectRetry(TestsExceptionFilter):
 
     def _run_test(self, dialect_name, exception, count, retries):
